#
# spec file for package mjpegtools
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mjpegtools
Version:        2.0.0
Release:        18.3
Summary:        MJPEG Video Capture and Processing Tools
License:        GPL-2.0
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://mjpeg.sourceforge.net/
%if 0%{?BUILD_ORIG}
Source0:        http://sourceforge.net/projects/mjpeg/files/mjpegtools/%{version}/mjpegtools-%{version}.tar.gz
%else
# WARNING: This is not a comment, but a real command to repack souce:
#%(sh %{_sourcedir}/mjpegtools-codecpatch.sh %{_sourcedir} mjpegtools-%{version}.tar.gz mjpegtools-%{version}-patched.tar.gz )
Source0:        %{name}-%{version}-patched.tar.gz
%endif
Source1:        mjpegtools-codecpatch.sh
Source2:        baselibs.conf
Patch0:         mjpegtools-cpuinfo.patch
Patch1:         mjpegtools-vector_alignment.patch
Patch2:         mjpegtools-getopt.patch
Patch3:         mjpegtools-writeable_strings.patch
Patch4:         mjpegtools-no_arch_tuning.patch
Patch5:         mjpegtools-config_h.patch
Patch6:         mjpegtools-v4l-2.6.38.patch
Patch7:         mjpegtools-gcc47.patch
Patch8:         mjpegtools-2.0.0-fix-bashisms.patch
Patch100:       mjpegtools-codecpatch.patch
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(gdk-x11-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-x11-2.0)
BuildRequires:  pkgconfig(libdv)
BuildRequires:  pkgconfig(libpng) >= 1.4
BuildRequires:  pkgconfig(libquicktime)
%if 0%{?suse_version} >= 1210
BuildRequires:  pkgconfig(libv4l1)
%endif
BuildRequires:  pkgconfig(SDL_gfx)
BuildRequires:  pkgconfig(sdl)
Requires(post):  info
Requires(preun): info

%define lib_version %(echo %{version} | cut -d. -f1-2)

%description
The mjpegtools allow for capture, playback, processing, and simple
editing of MJPEG AV data. The hardware I/O applications are intended
for use with Zoran MJPEG framegrabber-based hardware (see the
zoran-driver package), but the processing tools can be used with MJPEG
data from other sources as well.

%package -n libmjpegutils-2_0-0
Summary:        MJPEG Video Capture and Processing Tools
Group:          System/Libraries

%description -n libmjpegutils-2_0-0
The mjpegtools allow for capture, playback, processing, and simple
editing of MJPEG AV data. The hardware I/O applications are intended
for use with Zoran MJPEG framegrabber-based hardware (see the
zoran-driver package), but the processing tools can be used with MJPEG
data from other sources as well.

%package -n libmjpegutils-devel
Summary:        MJPEG Video Capture and Processing Tools
Group:          Development/Libraries/C and C++
Requires:       libmjpegutils-2_0-0 = %{version}
Provides:       mjpegtools-devel = %{version}
Obsoletes:      mjpegtools-devel < %{version}

%description -n libmjpegutils-devel
This package contains all files needed to develop code that uses the
mjpegtools libraries.

%prep
%setup -q
%patch0
%if 0%{?BUILD_ORIG}
%patch1
%endif
%patch2 -p1
%patch3 -p1
%patch4
%patch5
%if 0%{?suse_version} >= 1210
%patch6
%endif
%patch7 -p1
%patch8 -p1
%if ! 0%{?BUILD_ORIG}
# remove references to files removed by %%{name}-codecpatch.sh
%patch100
%endif

%build
%if 0%{?BUILD_ORIG}
sed -i~ '/currently broken/d' mpeg2enc/mpeg2enc.cc
diff -u mpeg2enc/mpeg2enc.cc* || :
%endif
autoreconf -vfi
EXTRAOPTS=""
%ifarch ppc ppc64
EXTRAOPTS="--disable-simd-accel"
%endif
%configure --disable-static --disable-arch_tuning $EXTRAOPTS
make %{?_smp_mflags}

%install
%make_install
# remove mpeg encoding
%if ! 0%{?BUILD_ORIG}
for app in lav2mpeg mp2enc mpeg2enc mpegtranscode; do
    rm -f %{buildroot}%{_bindir}/${app}
    rm -f %{buildroot}%{_mandir}/man1/${app}.*
done
%endif
rm %{buildroot}%{_libdir}/lib*.la

%post
%install_info --info-dir=%{_infodir} %{_infodir}/mjpeg-howto.info%{ext_info}

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/mjpeg-howto.info%{ext_info}

%post -n libmjpegutils-2_0-0 -p /sbin/ldconfig

%postun -n libmjpegutils-2_0-0 -p /sbin/ldconfig

%files
%defattr(0644, root, root, 0755)
%attr(0755,root,root) %{_bindir}/*
%{_mandir}/man1/*.1%{ext_man}
%{_mandir}/man5/*.5%{ext_man}
%{_infodir}/mjpeg-howto.info%{ext_info}

%files -n libmjpegutils-2_0-0
%defattr(0644, root, root, 0755)
%doc AUTHORS BUGS CHANGES COPYING HINTS NEWS PLANS README* TODO
%{_libdir}/lib*-%{lib_version}.so.*

%files -n libmjpegutils-devel
%defattr(0644, root, root, 0755)
%{_includedir}/mjpegtools/
%{_libdir}/liblavfile.so
%{_libdir}/liblavjpeg.so
%{_libdir}/liblavplay.so
%{_libdir}/liblavrec.so
%{_libdir}/libmjpegutils.so
%if 0%{?BUILD_ORIG}
%{_libdir}/libmpeg2encpp.so
%endif
%{_libdir}/libmplex2.so
%{_libdir}/pkgconfig/mjpegtools.pc

%changelog
* Thu Jan  8 2015 olaf@aepfle.de
- BuildRequire at least libpng 1.14 due to usage of
  PNG_TRANSFORM_GRAY_TO_RGB
* Mon Dec  1 2014 kstreitova@suse.com
- Added baselibs.conf as a source in the spec file (to avoid error
  message from the Factory check script).
* Fri Nov 29 2013 Led <ledest@gmail.com>
- fix bashisms in shell scripts
- fix shebang in lavtc.sh that contains bash-specific constructions
- add patches:
  * mjpegtools-2.0.0-fix-bashisms.patch
* Tue Apr  9 2013 cfarrell@suse.com
- license update: GPL-2.0
  ÃPresence of many GPL-2.0 licensed files in mplex/ y4mdenoise
* Fri Mar  1 2013 coolo@suse.com
- update license to new format
* Tue Jul  3 2012 meissner@suse.com
- disable simd-accel on ppc as it does not build with the
  reduced tarball
* Sun May  6 2012 reddwarf@opensuse.org
- Don't force a libpng version
- Modify %%attr use to make it compatible with old distros
* Thu Mar 15 2012 dimstar@opensuse.org
- Add mjpegtools-gcc47.patch: Fix build with gcc 4.7.
* Fri Dec  2 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Nov 15 2011 cmorve69@yahoo.es
- Update to 2.0.0
- Remove obsoleted patches
- Rename to follow SLPP
- Use pkgconfig()-type BuildRequires
- Spec-clean
* Sun Aug  7 2011 chris@computersalat.de
- fix BUILD_ORIG
  o add fix_lib_versioning-mpeg2enc patch (mpeg2enc/Makefile.am)
- add gtk2-devel (Gtk+ support for glav)
- remove author from descr
* Thu Jul  7 2011 idonmez@novell.com
- Add mjpegtools-v4l-2.6.38.patch: use the new v4l interface
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
- properly escape macro in comments (fix for RPMLINT warning)
* Wed Feb  9 2011 pth@suse.de
- Optimize the handling of CFLAGS.
- Don't use -fno-strict-aliasing as the compiler doesn't report
  any aliasing issues.
* Wed Feb  9 2011 pth@suse.de
- Use AC_PREREQ before AC_INIT
- Move AM_INIT_AUTOMAKE to just after AC_INIT
- Use LT_INIT to init libtool and pass disable-static as default.
- Only pass -release to libtool and not -release and -version-info,
  thus fixing the library naming.
- Add and use an option to configure to disable processor specific
  code tuning.
- Don't bother with patching .in files as they're regenerated by
  calling autoreconf.
* Thu Sep  2 2010 pgajdos@suse.cz
- fixed crash
- see http://bugs.gentoo.org/293919,
  https://qa.mandriva.com/show_bug.cgi?id=55450
* Mon Mar  1 2010 puzel@novell.com
- mjpegtools-1.9.0-fix-compiler-error.patch
  - fix build
* Sat Nov 21 2009 meissner@suse.de
- fuzz=0 for codec patch
* Thu Jun  4 2009 puzel@suse.cz
- add mjpegtools-fix-invalid-conversion.patch
  - fixes build with new gcc and glibc
* Mon Jan 19 2009 puzel@suse.cz
- update to 1.9.0 (bug fixes)
  - delete mjpegtools-jpeg2yuv_stdin.patch (fixed upstream)
  - delete mjpegtools-gcc43.patch (fixed upstream)
- set correct group for -devel package (Development/Libraries/C and C++)
* Thu Jun 26 2008 puzel@suse.cz
- update to 1.9.0rc3
  * bugfix release
- removed mjpegtools-includes.patch (fixed in upstream)
- removed mjpegtools-motionestbug.patch (fixed in upstream)
- removed mjpegtools-strcmp.patch (fixed in upstream)
* Tue May 13 2008 puzel@suse.cz
- added libpng-devel to BuildRequires [bnc #343848]
* Mon Jan  7 2008 ssommer@suse.de
- fix build with gcc43
* Sun Aug 12 2007 ro@suse.de
- fix build for BUILD_ORIG not set
* Fri Aug 10 2007 pcerny@suse.cz
- fixed dependency problems on ppc/ppc64 [#297568]
  (reenabling architecture dependent configure options)
- changed DISTRIBUTABLE to BUILD_ORIG
- patch for jpeg2yuv to detect EOF correctly (from upstream)
- patch names synchronization
* Sun Aug  5 2007 olh@suse.de
- getopt returns int, not char
  align vector buffers to 16 bytes
  mark one string constant as const
  build parallel
* Fri Jul 20 2007 pcerny@suse.cz
- removed dependece on avifile and some other packages
* Wed May  9 2007 pcerny@suse.cz
- update to 1.9.0rc2
* Mon Oct 16 2006 ro@suse.de
- fix build with current libquicktime
* Tue Mar 14 2006 ro@suse.de
- disable altivec also on ppc64 (not just on ppc)
* Fri Jan 27 2006 nadvornik@suse.cz
- fixed BuildRequires
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%install_info_prereq.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 29 2005 ro@suse.de
- overwrite cpuinfo.sh, the build-host is basically random
  and optimizing for a random cpu does not help
* Wed Oct 26 2005 rguenther@suse.de
- add missing include of assert.h to allow building with gcc 4.1
* Fri Oct 21 2005 kraxel@suse.de
- updated to 1.8.0.
- splitted away -devel package.
* Mon Sep 26 2005 sbrabec@suse.cz
- Force gtk2 using gtk1-compat-devel.
* Tue May  3 2005 pmladek@suse.cz
- added some more fixes to build with gcc4
* Tue Apr 19 2005 ro@suse.de
- fix build with gcc-4
* Thu Apr 22 2004 kraxel@suse.de
- add -fno-strict-aliasing.
* Thu Feb  5 2004 kraxel@suse.de
- update to 1.6.2-final.
* Thu Jan 22 2004 kraxel@suse.de
- updated to 1.6.2-rc4.
- some spec file cleanups.
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Aug 11 2003 ro@suse.de
- fix build with latest avifile
* Tue May 27 2003 kraxel@suse.de
- file list fixups.
* Mon Mar 10 2003 kraxel@suse.de
- ppc build fix.
* Tue Feb 25 2003 aj@suse.de
- Add missing assert includes.
* Mon Feb 17 2003 ro@suse.de
- fix last change
* Thu Feb 13 2003 sf@suse.de
- compile with -fPIC on archs != i386
  (needed for gstreamer-plugins)
* Thu Feb 13 2003 ro@suse.de
- added freetype2-devel
* Wed Feb 12 2003 ro@suse.de
- added expat to neededforbuild
* Tue Dec 10 2002 kraxel@suse.de
- updated to version 1.6.1
- splitted libmovtar into a new package
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Thu Jul  4 2002 ro@suse.de
- neededforbuild quicktime4linux -> libquicktime
* Tue Jun 25 2002 uli@suse.de
- build movtar with -fPIC
* Wed Jun 12 2002 uli@suse.de
- update -> 1.6.0 (final)
* Fri May 24 2002 meissner@suse.de
- %%_lib fixes.
* Fri Apr 26 2002 uli@suse.de
- update -> 1.6.0-rc2
- update jpeg-mmx -> 0.1.4-rc1
- update libmovtar -> 0.1.3-rc1
- ditched buildroot crap, it breaks movtar
- disabled cmov optimizations (no runtime detection)
- changed MPEGTOOLS switch to DISTRIBUTABLE (with inverse logic)
  to ensure consistency with other packages
* Wed Apr  3 2002 sf@suse.de
- update to 1.6.0-beta2
- gcc3 fix
- spec cleanup
- removed mjpegtools.dif
- added DV-support again, as mmx-detection in libdv is "fixed"
- added buildroot
* Fri Feb  8 2002 uli@suse.de
- build without DV support (causes reliable segfaults even on
  non-DV input)
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Fri Jan 25 2002 uli@suse.de
- update -> 1.6.0-beta1
* Wed Aug  8 2001 ro@suse.de
- changed neededforbuild <sdl> to <SDL>
- changed neededforbuild <sdl-devel> to <SDL-devel>
* Tue Jul 10 2001 uli@suse.de
- initial package
